/******************************************************************************

	imggen.c

	Generate image file filled with test pattern
	
	(c) 2007 by Ansgar Kueckes (kueckes@alice-dsl.net)

******************************************************************************/

#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <errno.h>

static char pattern[17] = { "0123456789ABCDEF" };

void print_usage(char *command)
{
	printf("Usage: %s <size> <imagefile>\n", command);
	return;
}

int main(int argc, char *argv[])
{
  char *outfile = 0;
  FILE *ofp;
  unsigned long i, j, block_count, size;
  
  if (argc < 3) { print_usage(argv[0]); exit(0); }

  /* command line processing */
  size = atoi(argv[1]);
  outfile = argv[2];
  
  if ((size % 256) != 0) {
  	printf("Size must be multiple of 256 (exiting).");
  	exit(0);
  }
  
  /* open image file */
  ofp = fopen( outfile, "wb");
  if (!ofp) { fprintf(stderr, "Could not open file \"%s\".\n", outfile); exit(-1); }

    
  block_count = size / 256;

  for (i=0; i<block_count; i++) {
  	fputc(i>>24&0xff, ofp);
  	fputc(i>>16&0xff, ofp);
  	fputc(i>>8&0xff, ofp);
  	fputc(i&0xff, ofp);
  	fprintf(ofp, "%s", pattern+4);
  	for (j=1; j<16; j++) {
  		fputc(j, ofp);
  		fprintf(ofp, "%s", pattern+1);
  	}
  }  
  
  /* cleanup */
  if (ofp) fclose(ofp);
  exit(0);
}
